@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2009-2010 Michael Howitz
+# Copyright (c) 2009-2011 Michael Howitz
 # See also LICENSE.txt
 
-from icemac.addressbook.i18n import MessageFactory as _
+from icemac.addressbook.i18n import _
 import gocept.cache.property
+import icemac.ab.importer.browser.resource
 import icemac.ab.importer.interfaces
+import icemac.addressbook.browser.resource
 import icemac.addressbook.interfaces
 import persistent.mapping
 import z3c.form.field
@@ -20,6 +22,7 @@ class ImportWizard(z3c.wizard.wizard.Wizard):
     label = _(u'Import Wizard')
 
     def setUpSteps(self):
+        icemac.ab.importer.browser.resource.import_css.need()
         return [
             z3c.wizard.step.addStep(self, 'editFile', weight=1),
             z3c.wizard.step.addStep(self, 'reader', weight=2),
@@ -58,6 +61,10 @@ def get_file_session(file, request):
 
 class Step(z3c.wizard.step.Step):
 
+    def update(self):
+        icemac.addressbook.browser.resource.form_css.need()
+        super(Step, self).update()
+
     @property
     def fields(self):
         return z3c.form.field.Fields(self.interface)
