@@ -1,20 +1,17 @@
-# Copyright (c) 2008-2010 Michael Howitz
+# Copyright (c) 2008-2011 Michael Howitz
 # See also LICENSE.txt
 
 import icemac.ab.importer.install
 import icemac.addressbook.addressbook
 import icemac.addressbook.testing
-import zope.component.globalregistry
-import zope.container.contained
-import zope.traversing.adapters
+import icemac.addressbook.utils
 
 
 class TestInstall(icemac.addressbook.testing.FunctionalTestCase):
 
     def assertLocalUtility(self, ab, iface):
-        self.assertTrue(
-            icemac.addressbook.addressbook.utility_locally_registered(ab, iface)
-            )
+        self.assertTrue(icemac.addressbook.utils.utility_locally_registered(
+            ab, iface))
 
     def assertAttribute(self, ab, attribute, iface):
         self.assertTrue(iface.providedBy(getattr(ab, attribute)))
@@ -26,7 +23,7 @@ class TestInstall(icemac.addressbook.testing.FunctionalTestCase):
 
     def setUp(self):
         super(TestInstall, self).setUp()
-        root = self.getRootFolder()
+        root = self.layer.getRootFolder()
         root['ab'] = self.ab = icemac.addressbook.utils.create_obj(
             icemac.addressbook.addressbook.AddressBook)
 
